<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>Kan inte utföra exklusiv låsning</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>En annan pakethanterare (som Synaptic eller apt-get), körs redan. Var vänlig stäng det programmet först</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>Du måste köra detta program som root</translation>
    </message>
</context>
<context>
    <name>mxcodecs</name>
    <message>
        <location filename="../mxcodecs.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX Codecs Installerare</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Det här programmet låter dig installera begränsade codecs som tillåter avancerade video och audio funktioner&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;I en del länder kan deras distribution vara begränsad så användaren måste följa lokala lagar.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Tar du lagligt ansvar för att ladda ner dessa codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Laddar ner codecs-filer</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Avbryt ändringarna och sedan sluta</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="97"/>
        <location filename="../mxcodecs.cpp" line="267"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>Genomför ändringarna och sedan sluta</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="121"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="177"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="180"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="217"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="220"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="104"/>
        <location filename="../mxcodecs.cpp" line="111"/>
        <location filename="../mxcodecs.cpp" line="119"/>
        <location filename="../mxcodecs.cpp" line="127"/>
        <location filename="../mxcodecs.cpp" line="136"/>
        <location filename="../mxcodecs.cpp" line="143"/>
        <location filename="../mxcodecs.cpp" line="152"/>
        <location filename="../mxcodecs.cpp" line="160"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Kör kommando...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="107"/>
        <location filename="../mxcodecs.cpp" line="123"/>
        <location filename="../mxcodecs.cpp" line="130"/>
        <location filename="../mxcodecs.cpp" line="139"/>
        <location filename="../mxcodecs.cpp" line="145"/>
        <location filename="../mxcodecs.cpp" line="156"/>
        <location filename="../mxcodecs.cpp" line="163"/>
        <location filename="../mxcodecs.cpp" line="192"/>
        <location filename="../mxcodecs.cpp" line="245"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="108"/>
        <location filename="../mxcodecs.cpp" line="124"/>
        <location filename="../mxcodecs.cpp" line="140"/>
        <location filename="../mxcodecs.cpp" line="157"/>
        <source>Cannot connect to the download site</source>
        <translation>Kan inte ansluta till nedladdningssidan</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="114"/>
        <location filename="../mxcodecs.cpp" line="131"/>
        <location filename="../mxcodecs.cpp" line="146"/>
        <location filename="../mxcodecs.cpp" line="164"/>
        <source>Error downloading %1</source>
        <translation>Fel vid nerladdning %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="169"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nerladdning Avslutad.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="188"/>
        <source>Installing downloaded files</source>
        <translation>Installerar nerladdade filer</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="193"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Inga nerladdade *.deb filer hittade.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="206"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Installerar...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="219"/>
        <source>Error installing %1</source>
        <translation>Fel vid installering %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="223"/>
        <source>Fix missing dependencies...</source>
        <translation>Fixa saknade beroenden...</translation>
    </message>
    <message>
        <source>Error running &apos;apt-get -fm install&apos; command</source>
        <translation type="vanished">Fel vid körandet av &apos;apt-get -fm install&apos; kommandot</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="225"/>
        <source>Error running %1 command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="237"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Installations-processen är avslutad&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="241"/>
        <source>Finished</source>
        <translation>Slutför</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="242"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Codecs-filerna har laddats ner och framgångsrikt installerats.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="246"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Processen avslutad. Fel har inträffat under installationen.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="260"/>
        <source>About MX Codecs</source>
        <translation>Om MX Codecs</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="261"/>
        <source>MX Codecs</source>
        <translation>MX Codecs</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="261"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="263"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Enkel codecs-nerladdare för MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="264"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="265"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="266"/>
        <location filename="../mxcodecs.cpp" line="276"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="283"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
</context>
</TS>
